#!/usr/bin/env python
# -*- coding: utf8 -*-

# *************************************************************************** #
#                                                                             #
#      Version 0.1 - 2013-08-01                                               #
#      Copyright (C) 2013 Marco Crippa                                        #
#                                                                             #
#      This program is free software; you can redistribute it and/or          #
#      modify it under the terms of the GNU General Public License            #
#      as published by the Free Software Foundation; either version 2         #
#      of the License, or (at your option) any later version.                 #
#                                                                             #
#      This program is distributed in the hope that it will be useful,        #
#      but WITHOUT ANY WARRANTY; without even the implied warranty of         #
#      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          #
#      GNU General Public License for more details.                           #
#                                                                             #
#      You should have received a copy of the GNU General Public License      #
#      along with this program; if not, write to the                          #
#      Free Software Foundation, Inc.,                                        #
#      51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA           #
#                                                                             #
# *************************************************************************** #


# Version 0.2 - 2020-10-17 MrQ: combined 22 plugs into one with an effect selection box, adding frames as desired.

from gimpfu import *

def gimp_instagram_effect( img, draw, effect, white, black):

	current_f=pdb.gimp_context_get_foreground()
	img.disable_undo()
	lg=pdb.gimp_layer_group_new(img)
	pdb.gimp_image_insert_layer(img, lg, None, 0)
	
	if effect==0:	# 1977	
		pdb.gimp_item_set_name(lg,"1977 Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"1977BG")

		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy, 0, 6, (0,60, 65,70, 255,255) )

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		l = pdb.gimp_layer_new(img,w,h,0,"1977Col",100.0,3)
		pdb.gimp_image_insert_layer(img, l, lg, 0)
		pdb.gimp_image_set_active_layer(img,l)
		pdb.gimp_context_set_foreground((227,255,215))
		pdb.gimp_edit_fill(l,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_mode(l,9)
		
	if effect==1:	# Amaro
		pdb.gimp_item_set_name(lg,"Amaro Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"amaroBG")
		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy, 1, 8, (0,30, 156,196, 205,203, 255,255) )
		pdb.gimp_curves_spline(drawCopy, 2, 10, (0,0, 61,67, 139,184, 200,206, 255,255) )
		pdb.gimp_curves_spline(drawCopy, 3, 8, (0,20, 146,184, 220,222, 255,255) )

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#create vignette
		v = pdb.gimp_layer_new(img,w,h,1,"vignette",100.0,17)
		pdb.gimp_image_insert_layer(img, v, lg, 0)
		pdb.gimp_image_set_active_layer(img,v)
		pdb.gimp_image_select_ellipse(img,0,0,0,w,h)
		if w>=h:
			lat=w
		else:
			lat=h
		pdb.gimp_selection_feather(img,lat/10)
		pdb.gimp_selection_invert(img)
		pdb.gimp_context_set_foreground((0,0,0))
		pdb.gimp_edit_fill(v,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_opacity(v,60)
		
	if effect==2:	# Apollo
		pdb.gimp_item_set_name(lg,"Apollo Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"apolloBG")

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]
		pdb.gimp_selection_clear(img)

		#copy image black and white
		BW=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, BW, lg, 0)
		pdb.gimp_item_set_name(BW,"apolloBlackWhite")
		pdb.gimp_desaturate_full(BW,0)
		pdb.gimp_layer_set_opacity(BW,50)


		#add vignette
		l = pdb.gimp_layer_new(img,w,h,1,"apolloVignette",100.0,0)
		pdb.gimp_image_insert_layer(img, l, lg, 0)
		pdb.gimp_image_set_active_layer(img,l)
		delta=(w/100)*5
		pdb.gimp_image_select_ellipse(img,0, 0-delta,0-delta, w+(delta*2),h+(delta*2) )
		feather=(w/100)*15
		pdb.gimp_selection_feather(img,feather)
		pdb.gimp_selection_invert(img)
		pdb.gimp_context_set_foreground((0,0,0))
		pdb.gimp_edit_fill(l,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_mode(l,0)
		pdb.gimp_layer_set_opacity(l,40)

		#add green layer
		green = pdb.gimp_layer_new(img,w,h,1,"apolloGreen",100.0,0)
		pdb.gimp_image_insert_layer(img, green, lg, 0)
		pdb.gimp_image_set_active_layer(img,green)
		pdb.gimp_context_set_foreground((62,205,42))
		pdb.gimp_edit_fill(green,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_opacity(green,40)
		pdb.gimp_layer_set_mode(green,5)	
	
	if effect==3:	# brannan
		pdb.gimp_item_set_name(lg,"Brannan Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"brannanBG")

		#copy image
		drawCopy2=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy2, lg, 0)
		pdb.gimp_item_set_name(drawCopy2,"brannanBG2")
		
		#desaturete image and overlay
		pdb.gimp_desaturate_full(drawCopy2,0)
		pdb.gimp_layer_set_mode(drawCopy2,5)
		pdb.gimp_layer_set_opacity(drawCopy2,37)

		#adjust hue saturation of bg
		pdb.gimp_hue_saturation(drawCopy,0, 0,0,-30)
		
		#merge layer
		ml=pdb.gimp_image_merge_down(img,drawCopy2,1)
		pdb.gimp_item_set_name(ml,"brannanBG")

		#adjust levels colors
		pdb.gimp_levels(ml, 0, 0, 255, 1.0, 9, 255)
		pdb.gimp_levels(ml, 1, 0, 228, 1.0, 23, 255)
		pdb.gimp_levels(ml, 2, 0, 255, 1.0, 3, 255)
		pdb.gimp_levels(ml, 3, 0, 239, 1.0, 12, 255)

		#adjust brightness contrast
		pdb.gimp_brightness_contrast(ml, -8, 25)

		#adjust levels colors
		pdb.gimp_levels(ml, 0, 0, 255, 0.91, 7, 255)
		pdb.gimp_levels(ml, 1, 0, 255, 1.0, 9, 255)
		pdb.gimp_levels(ml, 2, 0, 224, 1.0, 3, 255)
		pdb.gimp_levels(ml, 3, 0, 255, 0.94, 18, 255)

		#adjust brightness contrast
		pdb.gimp_brightness_contrast(ml, -4, -1)
		pdb.gimp_brightness_contrast(ml, 0, -14)

		
		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#add new layer
		l = pdb.gimp_layer_new(img,w,h,0,"brannanCol",100.0,3)
		pdb.gimp_image_insert_layer(img, l, lg, 0)
		pdb.gimp_image_set_active_layer(img,l)
		pdb.gimp_context_set_foreground((255,248,242))
		pdb.gimp_edit_fill(l,0)
		pdb.gimp_selection_clear(img)
	if effect==4:	# Earlybird
		pdb.gimp_item_set_name(lg,"Earlybird Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"earlybirdBG")

		#adjust hue, saturation and lightness
		pdb.gimp_hue_saturation(drawCopy,0,0,1,-30)

		#adjust levels colors
		pdb.gimp_levels(drawCopy, 0, 0, 255, 1.2, 0, 255)
		pdb.gimp_levels(drawCopy, 1, 0, 255, 1.0, 25, 255)

		#adjust brightness contrast
		pdb.gimp_brightness_contrast(drawCopy, 8, 20)

		#adjust hue, saturation and lightness
		pdb.gimp_hue_saturation(drawCopy,0,0,0,-15)

		#adjust levels colors
		pdb.gimp_levels(drawCopy, 0, 0, 235, 0.9, 0, 255)


		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#set new color layer
		l = pdb.gimp_layer_new(img,w,h,0,"earlybirdCol",100.0,3)
		pdb.gimp_image_insert_layer(img, l, lg, 0)
		pdb.gimp_image_set_active_layer(img,l)
		pdb.gimp_context_set_foreground((252,243,214))
		pdb.gimp_edit_fill(l,0)
		pdb.gimp_selection_clear(img)

		#create vignette
		v = pdb.gimp_layer_new(img,w,h,1,"vignette",100.0,17)
		pdb.gimp_image_insert_layer(img, v, lg, 0)
		pdb.gimp_image_set_active_layer(img,v)
		pdb.gimp_image_select_ellipse(img,0,0,0,w,h)
		if w>=h:
			lat=w
		else:
			lat=h
		pdb.gimp_selection_feather(img,lat/10)
		pdb.gimp_selection_invert(img)
		pdb.gimp_context_set_foreground((184,184,184))
		pdb.gimp_edit_fill(v,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_opacity(v,60)

	if effect==5:	# Gotham
		pdb.gimp_item_set_name(lg,"Gotham Effect")

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"gothamBG")
		pdb.gimp_desaturate_full(drawCopy,0)

		drawCopy2=pdb.gimp_layer_new_from_drawable(drawCopy,img)
		pdb.gimp_image_insert_layer(img, drawCopy2, lg, 0)
		pdb.gimp_item_set_name(drawCopy2,"gothamBG2")

		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy2, 3, 10, (0,0, 63,98, 128,128, 189,159, 255,255) )
		pdb.gimp_layer_set_mode(drawCopy2,18)

		#add some blur and noise
		drawCopy3=pdb.gimp_layer_new_from_drawable(drawCopy,img)
		pdb.gimp_image_insert_layer(img, drawCopy3, lg, 0)
		pdb.gimp_item_set_name(drawCopy3,"gothamBG3")
		pdb.plug_in_mblur(img,drawCopy3,0,256,0,0,0)
		pdb.gimp_layer_set_mode(drawCopy3,4)
		pdb.gimp_layer_set_opacity(drawCopy3,30)
		pdb.plug_in_rgb_noise(img,drawCopy3,0,1,0.10,0.10,0.10,0)

	if effect==6:	# Hefe
		pdb.gimp_item_set_name(lg,"Hefe Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img,drawCopy,lg,0)
		pdb.gimp_item_set_name(drawCopy,"hefeBG")

		#adjust brightness contrast
		pdb.gimp_brightness_contrast(drawCopy, 15, 25)
		
		#adjust hue saturation
		pdb.gimp_hue_saturation(drawCopy,0,5,0,-20)

		o=pdb.gimp_layer_new_from_drawable(drawCopy,img)
		pdb.gimp_image_insert_layer(img, o, lg, 0)
		pdb.gimp_item_set_name(o,"hefeOverlay")
		pdb.gimp_layer_set_mode(o,5)
		pdb.gimp_layer_set_opacity(o,40)

		ml=pdb.gimp_image_merge_down(img,o,1)

		#adjust brightness contrast
		pdb.gimp_brightness_contrast(ml, -15, 5)

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#add vignette
		l = pdb.gimp_layer_new(img,w,h,1,"hefeVignette",100.0,0)
		pdb.gimp_image_insert_layer(img, l, lg, 0)
		pdb.gimp_image_set_active_layer(img,l)

		newW=int( (w/100)*90 )
		newH=int( (h/100)*90 )
		pdb.gimp_image_select_rectangle(img,0,int((w-newW)/2),int((h-newH)/2),newW,newH)
		if w>=h:
			rd=int(w/3)
		else:
			rd=int(h/3)
		pdb.gimp_selection_feather(img,rd)
		pdb.gimp_selection_invert(img)
		pdb.gimp_context_set_foreground((181,181,181))
		pdb.gimp_edit_fill(l,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_mode(l,3)

	if effect==7:	# Hudson

		pdb.gimp_item_set_name(lg,"Hudson Effect")

		#copy image
		drawCopy2=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img,drawCopy2,lg,0)
		pdb.gimp_item_set_name(drawCopy2,"hudsonBG")

		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy2, 0, 4, (0,25, 255,255) )
		pdb.gimp_curves_spline(drawCopy2, 1, 10, (0,34, 29,49, 130,162, 201,217, 255,255) )
		pdb.gimp_curves_spline(drawCopy2, 2, 14, (0,0, 67,88, 126,159, 154,178, 201,220, 226,235, 255,255) )
		pdb.gimp_curves_spline(drawCopy2, 3, 12, (0,0, 67,91, 138,191, 204,231, 255,255) )

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#add color level
		pdb.gimp_context_set_foreground((128,153,190))
		pdb.gimp_context_set_background((47,27,27))

		l = pdb.gimp_layer_new(img,w,h,1,"hudsonColor",100.0,0)
		pdb.gimp_image_insert_layer(img, l, lg, 0)
		pdb.gimp_image_set_active_layer(img,l)

		pdb.gimp_edit_blend(l,0,0,2,100,0,0,0,0,4,2,1,w/2,h/2,w+(w/2),h/2)

		pdb.gimp_layer_set_opacity(l,75)
		pdb.gimp_layer_set_mode(l,5)
		
	if effect==8:	# Inkwell

		pdb.gimp_item_set_name(lg,"Inkwell Effect")
		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"inkwellBG")
		pdb.gimp_desaturate_full(drawCopy,0)

		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy, 0, 10, (0,0, 13,0, 83,125, 178,219, 255,255) )

		#adjust brightness contrast
		pdb.gimp_brightness_contrast(drawCopy,-15,15)
	
	if effect==9:	# Lofi
		pdb.gimp_item_set_name(lg,"Lofi Effect")

		#copy image
		drawCopy2=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img,drawCopy2,lg,0)
		pdb.gimp_item_set_name(drawCopy2,"lofiBG")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img,drawCopy,lg,0)
		pdb.gimp_item_set_name(drawCopy,"lofiGradMap")

		#set color for gradient map
		grad=pdb.gimp_gradient_new("lofiGradient")
		pdb.gimp_context_set_foreground((38,15,79))
		pdb.gimp_context_set_background((255,110,17))
		pdb.gimp_gradient_segment_set_left_color( grad, 0 ,pdb.gimp_context_get_foreground(), 100)
		pdb.gimp_gradient_segment_set_right_color( grad, 0 ,pdb.gimp_context_get_background(), 100)
		pdb.gimp_context_set_gradient(grad)
		pdb.plug_in_gradmap(img,drawCopy)
		pdb.gimp_gradient_delete(grad)
		pdb.gimp_layer_set_opacity(drawCopy,25)
		pdb.gimp_layer_set_mode(drawCopy,3)

		#adjust brightness contrast
		pdb.gimp_brightness_contrast(drawCopy2, 16, 10)
		
		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy2, 0, 6, (3,20, 61,61, 255,255) )

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#add vignette
		l = pdb.gimp_layer_new(img,w,h,1,"lofiVignette",100.0,0)
		pdb.gimp_image_insert_layer(img, l, lg, 0)
		pdb.gimp_image_set_active_layer(img,l)

		newW=int( (w/100)*90 )
		newH=int( (h/100)*90 )
		pdb.gimp_image_select_rectangle(img,0,int((w-newW)/2),int((h-newH)/2),newW,newH)
		if w>h:
			rd=int(w/3)
		else:
			rd=int(h/3)
		pdb.gimp_selection_feather(img,rd)
		pdb.gimp_selection_invert(img)
		pdb.gimp_context_set_foreground((0,0,0))
		pdb.gimp_edit_fill(l,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_mode(l,19)

	if effect==10:	# Lord Kelvin
		pdb.gimp_item_set_name(lg,"Lord Kelvin Effect")

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]
		pdb.gimp_selection_clear(img)

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"LordKelvinBG")
		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy, 0, 4, (10,0,255,255) )
		pdb.gimp_curves_spline(drawCopy, 1, 6, (0,63, 100,200, 255,255) )
		pdb.gimp_curves_spline(drawCopy, 2, 6, (0,30,180,190,255,210) )
		pdb.gimp_curves_spline(drawCopy, 3, 6, (0,90,177,114,255,188) )

		#add white border
		Wborder = pdb.gimp_layer_new(img,w,h,1,"whiteBorder",100.0,0)
		pdb.gimp_image_insert_layer(img, Wborder, lg, 0)
		pdb.gimp_image_set_active_layer(img,Wborder)
		pdb.gimp_context_set_foreground((255,255,255))
		pdb.gimp_image_select_rectangle(img, 0, 0,0, w,h )
		dimBorder=int( (w/100)*2 )
		if dimBorder<5:
			dimBorder=5
		pdb.gimp_selection_shrink(img, dimBorder)
		pdb.gimp_selection_invert(img)
		pdb.gimp_edit_fill(Wborder,0)
		pdb.gimp_selection_clear(img)

	if effect==11:	# Mayfair
		pdb.gimp_item_set_name(lg,"Mayfair Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"mayfairBG")

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]
		pdb.gimp_selection_clear(img)

		#add some noise
		noise = pdb.gimp_layer_new(img,w,h,1,"mayfairNoise",100.0,0)
		pdb.gimp_image_insert_layer(img, noise, lg, 0)
		pdb.gimp_image_set_active_layer(img,noise)
		pdb.gimp_context_set_foreground((0,0,0))
		pdb.gimp_edit_fill(noise,0)
	#	pdb.plug_in_rgb_noise(img,noise,1,0,0.20,0.20,0.20,0)
		pdb.plug_in_rgb_noise(img,noise,0,0,0.20,0.20,0.20,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_mode(noise,4)
		pdb.gimp_layer_set_opacity(noise,20)

		#central selection
		pdb.gimp_image_set_active_layer(img,drawCopy)
		nParti=6
		feather=(w/100)*10
		pdb.gimp_image_select_rectangle(img,0, (w/2)-(w/nParti), (h/2)-(h/nParti), (w/nParti)*2, (h/nParti)*2 )
		pdb.gimp_selection_feather(img,feather)
		pdb.gimp_edit_copy(drawCopy)
		sel = pdb.gimp_layer_new(img,w,h,1,"mayfairSel",100.0,0)
		pdb.gimp_image_insert_layer(img, sel, lg, 0)
		pdb.gimp_image_set_active_layer(img,sel)
		lSel = pdb.gimp_edit_paste(sel, 1)
		pdb.gimp_floating_sel_attach(lSel, sel)
		pdb.gimp_selection_clear(img)

		#adjust brightness contrast
		pdb.gimp_brightness_contrast(sel, 0, 25)

		#lateral selection
		latSel = pdb.gimp_layer_new(img,w,h,1,"mayfairLatSel",100.0,0)
		pdb.gimp_image_insert_layer(img, latSel, lg, 0)
		pdb.gimp_image_set_active_layer(img,latSel)
		wSel=(w/100)*10
		pdb.gimp_image_select_rectangle(img,0, w-wSel, 0, w, h )
		pdb.gimp_image_select_rectangle(img,0, 0, 0, wSel, h )
		feather=(w/100)*10
		pdb.gimp_selection_feather(img,feather)
		pdb.gimp_context_set_foreground((0,0,0))
		pdb.gimp_edit_fill(latSel,0)
		pdb.gimp_layer_set_mode(latSel,19)
		pdb.gimp_layer_set_opacity(latSel,70)
		pdb.gimp_selection_clear(img)

		#circular selection
		cSel = pdb.gimp_layer_new(img,w,h,1,"mayfairCSel",100.0,0)
		pdb.gimp_image_insert_layer(img, cSel, lg, 0)
		pdb.gimp_image_set_active_layer(img,cSel)
		pdb.gimp_layer_set_opacity(cSel,80)
		pdb.gimp_image_select_ellipse(img,0, (w/2)-(w/nParti), 0-(h/nParti), (w/nParti)*2, (h/nParti)*2 )
		pdb.gimp_image_select_ellipse(img,0, (w/2)-(w/nParti), h-(h/nParti), (w/nParti)*2, (h/nParti)*2 )
		feather=(w/100)*10
		pdb.gimp_selection_feather(img,feather)
		pdb.gimp_context_set_foreground((255,255,255))
		pdb.gimp_edit_fill(cSel,0)
		pdb.gimp_layer_set_mode(cSel,19)
		pdb.gimp_layer_set_opacity(cSel,55)
		pdb.gimp_selection_clear(img)

		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy, 0, 8, (0,0, 65,60, 185,190, 255,255) )
		pdb.gimp_curves_spline(sel, 0, 8, (0,0, 65,60, 185,190, 255,255) )

		#adjust levels colors
		pdb.gimp_levels(drawCopy, 0, 0, 255, 0.83, 0, 255)
		pdb.gimp_levels(sel, 0, 0, 255, 0.83, 0, 255)

		#adjust hue saturation of bg
		pdb.gimp_hue_saturation(drawCopy,0, 0,0,-20)
		pdb.gimp_hue_saturation(sel,0, 0,0,-20)
		
	if effect==12:	# Nashville
		pdb.gimp_item_set_name(lg,"Nashville Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"NashvilleBG")

		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy, 2, 4, (0,37, 255,255) )
		pdb.gimp_curves_spline(drawCopy, 3, 4, (0,131, 255,255) )

		#adjust levels colors
		pdb.gimp_levels(drawCopy, 0, 0, 236, 1.36, 0, 255)

		#adjust brightness contrast
		pdb.gimp_brightness_contrast(drawCopy, 6, 12)

		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy, 2, 4, (13,0, 255,255) )
		pdb.gimp_curves_spline(drawCopy, 3, 4, (88,0, 255,255) )

		#adjust brightness contrast
		pdb.gimp_brightness_contrast(drawCopy, -6, 5)

		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy, 1, 4, (0,4, 255,255) )
		pdb.gimp_curves_spline(drawCopy, 3, 4, (0,14, 255,255) )

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		l = pdb.gimp_layer_new(img,w,h,0,"NashvilleCol",100.0,3)
		pdb.gimp_image_insert_layer(img, l, lg, 0)

		pdb.gimp_image_set_active_layer(img,l)

		pdb.gimp_context_set_foreground((255,218,173))

		pdb.gimp_edit_fill(l,0)

		pdb.gimp_selection_clear(img)

	if effect==13:	# Poprocket
		pdb.gimp_item_set_name(lg,"Poprocket Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"poprocketBG")

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#add color1
		col = pdb.gimp_layer_new(img,w,h,1,"poprocketCol1",100.0,0)
		pdb.gimp_image_insert_layer(img, col, lg, 0)
		pdb.gimp_image_set_active_layer(img,col)

		#set color gradient
		delta=(w/100)*5
		pdb.gimp_context_set_foreground((206,39,70))
		pdb.gimp_edit_blend(col,2,0,2,100,0,0,0,0,4,2,1,w/2,h/2,w-delta,h/2)
		pdb.gimp_layer_set_mode(col,4)

		#add color2
		col2 = pdb.gimp_layer_new(img,w,h,1,"poprocketCol2",100.0,0)
		pdb.gimp_image_insert_layer(img, col2, lg, 0)
		pdb.gimp_image_set_active_layer(img,col2)

		#set color gradient
		delta=(w/100)*30
		pdb.gimp_context_set_foreground((15,5,46))
		pdb.gimp_edit_blend(col2,2,0,2,100,0,0,1,0,4,2,1,w/2,h/2,w+delta,h/2)
		pdb.gimp_layer_set_mode(col2,5)	
		
	if effect==14:	# Rise

		pdb.gimp_item_set_name(lg,"Rise Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"riseBG")

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#Add vignette layer
		vignette = pdb.gimp_layer_new(img,w,h,1,"riseVignette",100.0,0)
		pdb.gimp_image_insert_layer(img, vignette, lg, 0)

		#add some noise
		noise = pdb.gimp_layer_new(img,w,h,1,"riseNoise",100.0,0)
		pdb.gimp_image_insert_layer(img, noise, lg, 0)
		pdb.gimp_image_set_active_layer(img,noise)
		pdb.gimp_context_set_foreground((0,0,0))
		pdb.gimp_edit_fill(noise,0)
	#	pdb.plug_in_rgb_noise(img,noise,1,0,0.20,0.20,0.20,0)
		pdb.plug_in_rgb_noise(img,noise,0,0,0.50,0.50,0.50,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_mode(noise,4)
		pdb.gimp_layer_set_opacity(noise,20)

		#add warming level
		warm = pdb.gimp_layer_new(img,w,h,1,"riseWarming",100.0,0)
		pdb.gimp_image_insert_layer(img, warm, lg, 0)
		pdb.gimp_image_set_active_layer(img,warm)
		pdb.gimp_context_set_foreground((237,138,0))
		pdb.gimp_edit_fill(warm,0)
		pdb.gimp_layer_set_mode(warm,5)
		pdb.gimp_layer_set_opacity(warm,50)

		#adjust hue saturation of bg
		pdb.gimp_hue_saturation(drawCopy,0, 20,0,-50)

		#add vignette
		pdb.gimp_image_set_active_layer(img,vignette)
		nParti=6
		wBorder=int( (h/100)*5 )
		feather=(w/100)*10
		pdb.gimp_image_select_ellipse(img,0, 0-(w/nParti), 0+wBorder, w+(w/nParti)*2, h-(wBorder*2) )
		pdb.gimp_selection_invert(img)
		pdb.gimp_selection_feather(img,feather)
		#set color gradient
		pdb.gimp_context_set_foreground((0,0,0))
		pdb.gimp_edit_blend(vignette,2,0,2,100,0,0,1,0,4,2,1,w/2,h/2,w+(w/2),h/2)
		pdb.gimp_layer_set_mode(vignette,5)
		pdb.gimp_selection_clear(img)
		pdb.gimp_levels(drawCopy,0,0,255,1.23,0,255)
		
	if effect==15:	# Sierra
		pdb.gimp_item_set_name(lg,"Sierra Effect")

		#copy image
		drawCopy2=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img,drawCopy2,lg,0)
		pdb.gimp_item_set_name(drawCopy2,"sierraBG")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img,drawCopy,lg,0)
		pdb.gimp_item_set_name(drawCopy,"sierraGradMap")

		#set color for gradient map
		grad=pdb.gimp_gradient_new("sierraGradient")
		pdb.gimp_context_set_foreground((252,102,5))
		pdb.gimp_context_set_background((255,255,0))
		pdb.gimp_gradient_segment_range_split_midpoint(grad,0,1)
		pdb.gimp_gradient_segment_set_left_color( grad, 0 ,pdb.gimp_context_get_foreground(), 100)
		pdb.gimp_gradient_segment_set_right_color( grad, 0 ,pdb.gimp_context_get_background(), 100)
		pdb.gimp_gradient_segment_set_left_color( grad, 1 ,pdb.gimp_context_get_background(), 100)
		pdb.gimp_gradient_segment_set_right_color( grad, 1 ,pdb.gimp_context_get_foreground(), 100)
		pdb.gimp_context_set_gradient(grad)
		pdb.plug_in_gradmap(img,drawCopy)
		pdb.gimp_gradient_delete(grad)
		pdb.gimp_layer_set_opacity(drawCopy,20)
		pdb.gimp_layer_set_mode(drawCopy,3)

		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy2, 0, 4, (0,95, 255,255) )

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#add vignette
		l = pdb.gimp_layer_new(img,w,h,1,"sierraVignette",100.0,0)
		pdb.gimp_image_insert_layer(img, l, lg, 0)
		pdb.gimp_image_set_active_layer(img,l)

		pdb.gimp_image_select_ellipse(img,0,0,0,w,h)
		if w>h:
			lat=w
		else:
			lat=h
		pdb.gimp_selection_feather(img,lat/7)
		pdb.gimp_selection_invert(img)
		pdb.gimp_context_set_foreground((0,0,0))
		pdb.gimp_edit_fill(l,0)
		pdb.plug_in_rgb_noise(img,l,0,0,0.05,0.05,0.05,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_mode(l,19)

	if effect==16:	# Sutro
	
		pdb.gimp_item_set_name(lg,"Sutro Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"sutroBG")

		#adjust brightness contrast
		pdb.gimp_brightness_contrast(drawCopy, 55, 38)
	#	pdb.gimp_brightness_contrast(drawCopy, 10, 38)

		#adjust hue, saturation and lightness
		pdb.gimp_hue_saturation(drawCopy,0,0,0,-36)

		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy, 1, 4, (11,14, 255,241) )
		pdb.gimp_curves_spline(drawCopy, 2, 4, (0,4, 255,247) )
		pdb.gimp_curves_spline(drawCopy, 3, 8, (0,33, 44,53, 114,120, 252,231) )

		#adjust brightness contrast
		pdb.gimp_brightness_contrast(drawCopy, -30, 5)

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#create vignette
		v = pdb.gimp_layer_new(img,w,h,1,"sutroVignette",100.0,17)
		pdb.gimp_image_insert_layer(img, v, lg, 0)
		pdb.gimp_image_set_active_layer(img,v)
		pdb.gimp_image_select_rectangle(img,0,int((w/100)*10),int((h/100)*10),int((w/100)*80),int((h/100)*80))
		feather=50
		pdb.gimp_selection_feather(img,feather)
		pdb.gimp_selection_invert(img)
		pdb.gimp_context_set_foreground((168,168,168))
		pdb.gimp_edit_fill(v,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_mode(v,17)
		pdb.gimp_layer_set_opacity(v,30)

		#add warming level
		warm = pdb.gimp_layer_new(img,w,h,1,"sutroWarming",100.0,0)
		pdb.gimp_image_insert_layer(img, warm, lg, 0)
		pdb.gimp_image_set_active_layer(img,warm)
		pdb.gimp_context_set_foreground((237,138,0))
		pdb.gimp_edit_fill(warm,0)
		pdb.gimp_layer_set_mode(warm,10)
		pdb.gimp_layer_set_opacity(warm,10)	

	if effect==17:	# Toaster

		pdb.gimp_item_set_name(lg,"Toaster Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"toasterBG")

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#mask layer
		maskL=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, maskL, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"toasterMask")
		pdb.gimp_image_set_active_layer(img,maskL)

		#adjust curves colors
		pdb.gimp_curves_spline(maskL, 0, 4, (25,0, 255,255) )

		#create mask
		lm = pdb.gimp_layer_create_mask(maskL,0)
		pdb.gimp_layer_add_mask(maskL,lm)
		#add vignette
		pdb.gimp_image_select_ellipse(img,0, 0,0, w,h )
		feather=(w/100)*20
		pdb.gimp_selection_feather(img,feather)
		pdb.gimp_context_set_foreground((0,0,0))
		pdb.gimp_edit_fill(lm,0)
		pdb.gimp_selection_clear(img)

		#gradient layer
		gradL=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img,gradL,lg,0)
		pdb.gimp_item_set_name(gradL,"toasterGradMap")

		#set color for gradient map
		grad=pdb.gimp_gradient_new("toasterGradient")
		pdb.gimp_context_set_foreground((58,10,89))
		pdb.gimp_context_set_background((254,169,87))
		pdb.gimp_gradient_segment_set_left_color( grad, 0 ,pdb.gimp_context_get_foreground(), 100)
		pdb.gimp_gradient_segment_set_right_color( grad, 0 ,pdb.gimp_context_get_background(), 100)
		pdb.gimp_context_set_gradient(grad)
		pdb.plug_in_gradmap(img,gradL)
		pdb.gimp_gradient_delete(grad)
		pdb.gimp_layer_set_opacity(gradL,70)

	if effect==18:    # Valencia
		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]
		pdb.gimp_selection_clear(img)

		pdb.gimp_item_set_name(lg,"Valencia Effect")

		#copy image
		drawCopy2=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy2, lg, 0)
		pdb.gimp_item_set_name(drawCopy2,"valenciaBG")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"valenciaColor")
		pdb.gimp_layer_set_mode(drawCopy,3)

		pdb.gimp_selection_all
		pdb.gimp_context_set_foreground((246,221,173))
		pdb.gimp_edit_fill(drawCopy,0)
		pdb.gimp_selection_clear(img)

		#merge layer
		m=pdb.gimp_image_merge_down(img,drawCopy,1)

		#adjust curves colors
		pdb.gimp_curves_spline(m, 0, 8, (0,50, 75,110, 175,220, 255,255) )

		#adjust levels colors
		pdb.gimp_levels(m, 3, 0, 255, 1.0, 126, 255)
		
	if effect==19:    # Walden
		pdb.gimp_item_set_name(lg,"Walden Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"waldenBG")

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]
		pdb.gimp_selection_clear(img)

		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy, 0, 4, (12,0, 255,255) )
		pdb.gimp_curves_spline(drawCopy, 1, 4, (10,0, 247,255) )
		pdb.gimp_curves_spline(drawCopy, 3, 4, (0,38, 255,203) )

		#adjust levels colors
		pdb.gimp_levels(drawCopy, 0, 0, 235, 1.17, 55, 255)

		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy, 0, 6, (41,0, 125,124, 255,255) )

		#set color gradient vignette layer
		vign = pdb.gimp_layer_new(img,w,h,1,"waldenVignette",100.0,0)
		pdb.gimp_image_insert_layer(img, vign, lg, 0)
		pdb.gimp_image_set_active_layer(img,vign)
		delta=(w/100)*30
		pdb.gimp_context_set_foreground((0,0,0))
		pdb.gimp_edit_blend(vign,2,0,2,100,0,0,1,0,4,2,1, 0,0,w*2,h*2)
		pdb.gimp_layer_set_mode(vign,19)

	if effect==20:    # Willow

		pdb.gimp_item_set_name(lg,"Willow Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img,drawCopy,lg,0)
		pdb.gimp_item_set_name(drawCopy,"willowBG")

		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]

		#add some noise
		noise = pdb.gimp_layer_new(img,w,h,1,"willowNoise",100.0,0)
		pdb.gimp_image_insert_layer(img, noise, lg, 0)
		pdb.gimp_image_set_active_layer(img,noise)
		pdb.gimp_context_set_foreground((0,0,0))
		pdb.gimp_edit_fill(noise,0)
		pdb.plug_in_rgb_noise(img,noise,0,0,0.5,0.5,0.5,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_mode(noise,4)
		pdb.gimp_layer_set_opacity(noise,20)

		#turn black and white
		pdb.gimp_desaturate_full(drawCopy,1)

		#add flare
		flare = pdb.gimp_layer_new(img,w,h,1,"willowFlare",100.0,0)
		pdb.gimp_image_insert_layer(img, flare, lg, 0)
		pdb.gimp_image_set_active_layer(img,flare)

		#set color gradient
		pdb.gimp_context_set_foreground((255,255,255))
		pdb.gimp_edit_blend(flare,2,0,2,100,0,0,0,0,4,2,1,w/2,h/2,w,h/2)
		pdb.gimp_layer_set_mode(flare,19)


		#add vignette
		l = pdb.gimp_layer_new(img,w,h,1,"sierraVignette",100.0,0)
		pdb.gimp_image_insert_layer(img, l, lg, 0)
		pdb.gimp_image_set_active_layer(img,l)

		delta=80
		pdb.gimp_image_select_round_rectangle(img,0,w/delta,h/delta,w-2*(w/delta),h-2*(h/delta),50,50)
		feather=30
		pdb.gimp_selection_feather(img,feather)
		pdb.gimp_selection_invert(img)
		pdb.gimp_edit_fill(l,0)
		pdb.gimp_selection_clear(img)
		pdb.gimp_layer_set_mode(l,19)
		
	if effect==21:    #	X-Pro II	
		pdb.gimp_selection_all
		sel_size=pdb.gimp_selection_bounds(img)
		w=sel_size[3]-sel_size[1]
		h=sel_size[4]-sel_size[2]
		pdb.gimp_selection_clear(img)

		pdb.gimp_item_set_name(lg,"XProII Effect")

		#copy image
		drawCopy=pdb.gimp_layer_new_from_drawable(draw,img)
		pdb.gimp_image_insert_layer(img, drawCopy, lg, 0)
		pdb.gimp_item_set_name(drawCopy,"XproIIBG")
		#adjust curves colors
		pdb.gimp_curves_spline(drawCopy, 0, 10, (0,0, 62,45, 128,128, 187,204, 255,255) )
		pdb.gimp_curves_spline(drawCopy, 1, 12, (0,0, 54,30, 105,86, 148,144, 210,209, 255,255) )
		pdb.gimp_curves_spline(drawCopy, 2, 8, (0,0, 87,61, 231,231, 255,255) )
		pdb.gimp_curves_spline(drawCopy, 3, 8, (0,25, 76,82, 163,149, 255,180) )		
##############################################################################################################
##############################################################################################################	
	
	#add white border
	if white:	
		Wborder = pdb.gimp_layer_new(img,w,h,1,"whiteBorder",100.0,0)
		pdb.gimp_image_insert_layer(img, Wborder, lg, 0)
		pdb.gimp_image_set_active_layer(img,Wborder)
		pdb.gimp_context_set_foreground((255,255,255))
		pdb.gimp_image_select_rectangle(img, 0, 0,0, w,h )
		dimBorder=int( (w/100)*2 )
		if dimBorder<5:
			dimBorder=5
		pdb.gimp_selection_shrink(img, dimBorder)
		pdb.gimp_selection_invert(img)
		pdb.gimp_edit_fill(Wborder,0)
		pdb.gimp_selection_clear(img)
	
	#add black border
	if black:		
		Bborder = pdb.gimp_layer_new(img,w,h,1,"blackBorder",100.0,0)
		pdb.gimp_image_insert_layer(img, Bborder, lg, 0)
		pdb.gimp_image_set_active_layer(img,Bborder)
		pdb.gimp_context_set_foreground((0,0,0))
		pdb.gimp_image_select_rectangle(img, 0, 0,0, w,h )
		dimBorder=int( (w/100)*2 )
		if dimBorder<5:
			dimBorder=5
		pdb.gimp_selection_shrink(img, dimBorder)
		pdb.gimp_selection_invert(img)
		pdb.gimp_edit_fill(Bborder,0)
		pdb.gimp_selection_clear(img)

	img.enable_undo()

	pdb.gimp_context_set_foreground(current_f)

register( "gimp_instagram_effect",
  "Add Instagram effect",
  "Add Instagram effect",
  "Marco Crippa/MrQ",
  "GPL",
  "2013/2020",
  "Instagram Effect...",
  'RGB*',
  [
		(PF_IMAGE, "image", "", None),
		(PF_DRAWABLE, "drawable", "", None),
		(PF_OPTION, "effect", "Instagram Effect:", 1, [" 1977 "," Amaro "," Apollo ", " Brannan ", " Earlybird ", " Gotham ", " Hefe ", " Hudson ", " Inkwell ", " Lofi ",
		" Lord Kelvin ", " Mayfair ", " Nashville ", " Poprocket ", " Rise ", " Sierra ", " Sutro ", " Toaster ", " Valencia ", " Walden ", " Willow ", " X-Pro II "]), 
		(PF_BOOL, "white", "Add white border?", True),
		(PF_BOOL, "black", "Add black border?", True),			
  ],
  [],
	gimp_instagram_effect,
	menu="<Image>/Filters/Artistic/",
  )

main()


